aboutsummaryrefslogtreecommitdiffstats
path: root/common/timing.cc
diff options
context:
space:
mode:
Diffstat (limited to 'common/timing.cc')
-rw-r--r--common/timing.cc9
1 files changed, 5 insertions, 4 deletions
diff --git a/common/timing.cc b/common/timing.cc
index 1d69861b..1b3fd040 100644
--- a/common/timing.cc
+++ b/common/timing.cc
@@ -157,11 +157,12 @@ void assign_budget(Context *ctx, bool quiet)
}
}
- // If user has not specified a frequency, dynamically adjust the target
- // frequency to be the current maximum
- if (!ctx->user_freq) {
+ // For slack redistribution, if user has not specified a frequency
+ // dynamically adjust the target frequency to be the currently
+ // achieved maximum
+ if (!ctx->user_freq && ctx->slack_redist_iter > 0) {
ctx->target_freq = 1e12 / (default_slack - min_slack);
- if (ctx->verbose)
+ /*if (ctx->verbose)*/
log_info("minimum slack for this assign = %d, target Fmax for next update = %.2f MHz\n", min_slack,
ctx->target_freq / 1e6);
}